@@ -51,8 +51,8 @@ verror(const char *fmt, ...)
     char newfmt[2048];
     va_list argv;
     va_start(argv,fmt);
-    strcpy(newfmt,"netCDF classic: not supported: ");
-    strncat(newfmt,fmt,2000);
+    strncpy(newfmt,"netCDF classic: not supported: ",sizeof(newfmt));
+    strlcat(newfmt,fmt,sizeof(newfmt));
     vderror(newfmt,argv);
     va_end(argv);
 }
